@@ -1,5 +1,7 @@
+{-# LANGUAGE OverloadedStrings #-}
 module Main where
 
+import qualified Data.ByteString.Char8 as BC8
 import Control.Concurrent
 import Control.Exception
 
@@ -30,5 +32,5 @@ doTest =
             _ <- addWatch inot [AllEvents] testPath $ \_event -> do
                 putMVar mvar1 ()
                 takeMVar mvar2 -- hangs here
-            write testPath
+            write (BC8.unpack testPath)
             takeMVar mvar1
